<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package The Blogging
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />
    <link rel="profile" href="http://gmpg.org/xfn/11">
    <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>">

    <?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>
<?php
if ( function_exists( 'wp_body_open' ) ) {
    wp_body_open();
}
?>
<?php if ((the_blogging_get_option('enable_preloader')) == 1) { ?>
    <div class="preloader">
        <div class="twp-loader">
            <div class="dot">
                <div class="first"></div>
            </div>
            <div class="dot"></div>
            <div class="dot"></div>
            <div class="dot"></div>
        </div>
    </div>
<?php } ?>
<!-- full-screen-layout/boxed-layout -->
<?php if (the_blogging_get_option('homepage_layout_option') == 'full-width') {
    $the_blogging_homepage_layout = 'full-screen-layout';
} elseif (the_blogging_get_option('homepage_layout_option') == 'boxed') {
    $the_blogging_homepage_layout = 'boxed-layout';
} ?>
<div id="page" class="site site-bg <?php echo esc_attr($the_blogging_homepage_layout); ?>">
    <a class="skip-link screen-reader-text" href="#main"><?php esc_html_e('Skip to content', 'the-blogging'); ?></a>

    <?php get_template_part( 'template-parts/header/header', 'top' ); ?>
    <header id="masthead" class="site-header" role="banner">
        <div class="container">
            <div class="header-main">
                <div class="nav-left">
                    <div class="site-branding">
                        <div class="branding-wrapper">
                            <?php the_blogging_the_custom_logo(); ?>
                            <span class="site-title">
                                <a href="<?php echo esc_url(home_url('/')); ?>" rel="home">
                                    <?php bloginfo('name'); ?>
                                </a>
                            </span>
                            <?php $description = get_bloginfo('description', 'display');
                            if ($description || is_customize_preview()) : ?>
                                <p class="site-description">
                                    <?php echo esc_html($description); ?>
                                </p>
                            <?php
                            endif; ?>
                        </div>
                    </div>

                    <nav class="hidden-xs hidden-sm main-navigation" role="navigation">
                        <?php wp_nav_menu(array(
                            'theme_location' => 'primary',
                            'menu_id' => 'primary-menu',
                            'container' => 'div',
                            'container_class' => 'menu'
                        )); ?>
                    </nav>
                </div>
                <div class="nav-right">
                    <?php if ( class_exists( 'WooCommerce' ) ): ?>
                        <div class="nav-items twp-minicart">
                            <?php the_blogging_woocommerce_header_cart(); ?>
                        </div>
                    <?php endif; ?>

                    <?php if (1 == the_blogging_get_option('enable_top_header_search')) { ?>
                        <div class="nav-items icon-search">
                            <i class="ion-ios-search-strong meta-icon meta-icon-medium"></i>
                        </div>
                    <?php } ?>
                    <div class="nav-items toggle-menu" aria-controls="primary-menu" aria-expanded="false">
                        <a class="offcanvas-toggle" href="#">
                            <div class="twp-hamburger">
                                <span></span>
                                <span></span>
                                <span></span>
                            </div>
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </header><!-- #masthead -->
    <div class="search-box">
        <div class="container">
            <div class="row">
                <div class="col-sm-11">
                    <?php get_search_form(); ?>
                </div>
                <div class="col-sm-1">
                    <div class="close-popup"></div>
                </div>
            </div>
        </div>
    </div>

    <?php get_template_part( 'template-parts/header/header', 'categories' ); ?>


    <!-- Innerpage Header Begins Here -->
    <?php
    if (is_home()) {
        $the_blogging_slider_layout = esc_attr(the_blogging_get_option('slider_section_layout'));
        if ($the_blogging_slider_layout == 'twp-slider-1') {
            do_action('the_blogging_action_slider_post_1');
        } else {
            do_action('the_blogging_action_slider_post_2');
        }
        // carousel sldier
        do_action('the_blogging_action_carousel_post');
        // featured blog
        do_action('the_blogging_action_featured_blog_post');
        
        do_action('the_blogging_action_full_width_carousel_post');

        do_action('the_blogging_action_fullwidth_featured_blog');
    } elseif (is_front_page()) {
        $the_blogging_slider_layout = esc_attr(the_blogging_get_option('slider_section_layout'));
        if ($the_blogging_slider_layout == 'twp-slider-1') {
            do_action('the_blogging_action_slider_post_1');
        } else {
            do_action('the_blogging_action_slider_post_2');
        }
        // carousel sldier
        do_action('the_blogging_action_carousel_post');
        // featured blog
        do_action('the_blogging_action_featured_blog_post');
        
        do_action('the_blogging_action_full_width_carousel_post');
        do_action('the_blogging_action_fullwidth_featured_blog');
        
        do_action('the-blogging-page-inner-title');
    } else {
        do_action('the-blogging-page-inner-title');
    }
    ?>
    <!-- Innerpage Header Ends Here -->
    <div id="content" class="site-content">